{% extends "bee_django_report/base.html" %}
{% load bootstrap3 %}
{% load static %}
{% block content %}
    {% include 'bee_django_report/logo.html' %}
    {% include 'bee_django_report/nav.html' %}
{#    <h4>修改【{{ mentor_name }}】</h4>#}
    <form method="post">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}